@@ -33,9 +33,10 @@
 #  define KSCREENLOCKER_DEPRECATED_NO_EXPORT KSCREENLOCKER_NO_EXPORT KSCREENLOCKER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KSCREENLOCKER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KSCREENLOCKER_NO_DEPRECATED
+#    define KSCREENLOCKER_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KSCREENLOCKER_EXPORT_H */
